==> dna-repository-0.5-sources.jar: org/jboss/dna/repository/sequencer/SequencerException.java <==
/*
 * JBoss DNA (http://www.jboss.org/dna)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors. 
 *
 * JBoss DNA is free software. Unless otherwise indicated, all code in JBoss DNA
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * JBoss DNA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.dna.repository.sequencer;

/**
 * @author Randall Hauch
 */
public class SequencerException extends RuntimeException {

    /**
     */
    private static final long serialVersionUID = -7610898771539657335L;

    /**
     */
    public SequencerException() {
    }

    /**
     * @param message
     */
    public SequencerException( String message ) {
        super(message);
    }

    /**
     * @param cause
     */
    public SequencerException( Throwable cause ) {
        super(cause);
    }

    /**
     * @param message
     * @param cause
     */
    public SequencerException( String message, Throwable cause ) {
        super(message, cause);
    }

}

==> dna-repository-0.7-sources.jar: org/jboss/dna/repository/sequencer/SequencerException.java <==
/*
 * JBoss DNA (http://www.jboss.org/dna)
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * See the AUTHORS.txt file in the distribution for a full listing of 
 * individual contributors. 
 *
 * JBoss DNA is free software. Unless otherwise indicated, all code in JBoss DNA
 * is licensed to you under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * JBoss DNA is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.dna.repository.sequencer;

import net.jcip.annotations.Immutable;

/**
 * A runtime exception that denotes an error within a sequencer.
 */
@Immutable
public class SequencerException extends RuntimeException {

    /**
     */
    private static final long serialVersionUID = -7610898771539657335L;

    /**
     */
    public SequencerException() {
    }

    /**
     * @param message
     */
    public SequencerException( String message ) {
        super(message);
    }

    /**
     * @param cause
     */
    public SequencerException( Throwable cause ) {
        super(cause);
    }

    /**
     * @param message
     * @param cause
     */
    public SequencerException( String message,
                               Throwable cause ) {
        super(message, cause);
    }

}
